@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: common.c,v 1.87 2007/08/17 17:18:28 evertonm Exp $ */
+/* $Id: common.c,v 1.89 2007/08/30 15:08:00 evertonm Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -43,12 +43,15 @@ const char * const NEPIM_LABEL_PARTIAL      = "prt";
 const char * const NEPIM_LABEL_TOTAL        = "avg";
 const char * const NEPIM_LABEL_TOTAL_BROKEN = "avg(broken)";
 
+const char * const NEPIM_MSG_KEEPALIVES_SCHED = "scheduling sending of keepalives";
+const char * const NEPIM_MSG_KEEPALIVES_MISS  = "peer not sending keepalives? (see option -K)";
+
 static int line = 0;
 
 
 const char *nepim_version()
 {
-  return "0.41";
+  return "0.42";
 }
 
 static void header(FILE *out, int ident, int udp)
