@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: common.h,v 1.28 2007/08/17 17:12:47 evertonm Exp $ */
+/* $Id: common.h,v 1.29 2007/08/30 15:08:00 evertonm Exp $ */
 
 #ifndef NEPIM_COMMON_H
 #define NEPIM_COMMON_H
@@ -41,6 +41,9 @@ MA 02110-1301 USA
 extern const char * const NEPIM_LABEL_PARTIAL;
 extern const char * const NEPIM_LABEL_TOTAL;
 
+extern const char * const NEPIM_MSG_KEEPALIVES_SCHED;
+extern const char * const NEPIM_MSG_KEEPALIVES_MISS;
+
 const char *nepim_version();
 
 void nepim_pipe_stat(FILE *out, struct timeval now,
