@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: greet.c,v 1.18 2006/06/02 14:24:38 evertonm Exp $ */
+/* $Id: greet.c,v 1.20 2007/03/23 12:40:05 evertonm Exp $ */
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -37,6 +37,8 @@ const char *GREET_TEST_DURATION     = "test_duration=";
 const char *GREET_WRITE_DELAY       = "write_delay=";
 const char *GREET_SERVER_KA_SEND    = "server_ka_send=";
 const char *GREET_SERVER_KA_REQUIRE = "server_ka_req=";
+const char *GREET_SERVER_KA_TIMEOUT = "server_ka_tmout=";
+const char *GREET_SERVER_KA_DELAY   = "server_ka_delay=";
 const char *GREET_SEED              = "seed=";
 const char *GREET_VERIFY_DATA       = "verify_data=";
 const char *GREET_RANDOM_FILL       = "random_fill=";
@@ -73,7 +75,7 @@ int nepim_write_greetings(const nepim_greet_t *opt, char *buf, int buf_size)
                 "hello"
 		" %s%d %s%lld"
                 " %s%d %s%d %s%d"
-                " %s%ld %s%d %s%d"
+                " %s%ld %s%d %s%d %s%d %s%d"
 		" %s0x%08x %s%d %s%d %s0x%02x %s%d"
 		" %s%d %s%d %s%d"
 		" %s%d %s%d %s%d %s%d"
@@ -86,6 +88,8 @@ int nepim_write_greetings(const nepim_greet_t *opt, char *buf, int buf_size)
                 GREET_WRITE_DELAY,       opt->write_delay,
                 GREET_SERVER_KA_SEND,    opt->keepalive_must_send,
                 GREET_SERVER_KA_REQUIRE, opt->keepalive_require,
+                GREET_SERVER_KA_TIMEOUT, opt->keepalive_timeout,
+                GREET_SERVER_KA_DELAY,   opt->keepalive_send_delay,
                 GREET_SEED,              opt->seed,
                 GREET_VERIFY_DATA,       opt->verify_data,
                 GREET_RANDOM_FILL,       opt->random_fill,
@@ -111,7 +115,7 @@ int nepim_write_greetings(const nepim_greet_t *opt, char *buf, int buf_size)
   return pr;
 }
 
-int nepim_parse_greetings(nepim_greet_t *opt, 
+int nepim_parse_greetings(nepim_greet_t *opt, int is_tcp,
                           const char *buf, const char *past_end)
 {
   char tmp[past_end - buf + 1];
@@ -127,6 +131,8 @@ int nepim_parse_greetings(nepim_greet_t *opt,
   const int GREET_WRITE_DELAY_LEN       = strlen(GREET_WRITE_DELAY);
   const int GREET_SERVER_KA_SEND_LEN    = strlen(GREET_SERVER_KA_SEND);
   const int GREET_SERVER_KA_REQUIRE_LEN = strlen(GREET_SERVER_KA_REQUIRE);
+  const int GREET_SERVER_KA_TIMEOUT_LEN = strlen(GREET_SERVER_KA_TIMEOUT);
+  const int GREET_SERVER_KA_DELAY_LEN   = strlen(GREET_SERVER_KA_DELAY);
   const int GREET_SEED_LEN              = strlen(GREET_SEED);
   const int GREET_VERIFY_DATA_LEN       = strlen(GREET_VERIFY_DATA);
   const int GREET_RANDOM_FILL_LEN       = strlen(GREET_RANDOM_FILL);
@@ -149,6 +155,8 @@ int nepim_parse_greetings(nepim_greet_t *opt,
   long      write_delay       = -2;
   int       server_ka_send    = -2;
   int       server_ka_require = -2;
+  int       server_ka_timeout = -2;
+  int       server_ka_delay   = -2;
   unsigned  seed              = -2;
   int       verify_data       = -2;
   int       random_fill       = -2;
@@ -221,6 +229,16 @@ int nepim_parse_greetings(nepim_greet_t *opt,
       continue;
     }
 
+    if (!strncmp(tok, GREET_SERVER_KA_TIMEOUT, GREET_SERVER_KA_TIMEOUT_LEN)) {
+      server_ka_timeout = atoi(tok + GREET_SERVER_KA_TIMEOUT_LEN);
+      continue;
+    }
+
+    if (!strncmp(tok, GREET_SERVER_KA_DELAY, GREET_SERVER_KA_DELAY_LEN)) {
+      server_ka_delay = atoi(tok + GREET_SERVER_KA_DELAY_LEN);
+      continue;
+    }
+
     if (!strncmp(tok, GREET_SEED, GREET_SEED_LEN)) {
       if (sscanf(tok + GREET_SEED_LEN, "%x", &seed) != 1) {
         fprintf(stderr, "%s: illegal seed value\n",
@@ -332,26 +350,45 @@ int nepim_parse_greetings(nepim_greet_t *opt,
   if (write_delay < 0)
     write_delay = nepim_global.write_delay;
 
-  opt->must_send           = server_send;
-  opt->bit_rate            = bit_rate;
-  opt->pkt_rate            = pkt_rate;
-  opt->stat_interval       = stat_interval;
-  opt->test_duration       = test_duration;
-  opt->write_delay         = write_delay;
-  opt->keepalive_must_send = server_ka_send;
-  opt->keepalive_require   = server_ka_require;
-  opt->seed                = seed;
-  opt->verify_data         = verify_data;
-  opt->random_fill         = random_fill;
-  opt->fill_byte           = (unsigned char) fill_byte;
-  opt->pause_duration      = pause_duration;
-  opt->socket_keepalive    = socket_keepalive;
-  opt->nagle               = nagle;
-  opt->overhead            = overhead;
-  opt->sweep_random        = sweep_random;
-  opt->sweep_step          = sweep_step;
-  opt->write_floor         = write_floor;
-  opt->write_ceil          = write_ceil;
+  if (is_tcp) {
+    if (server_ka_timeout == -2) {
+      server_ka_timeout = nepim_global.tcp_keepalive_recv_timer;
+    }
+    if (server_ka_delay == -2) {
+      server_ka_delay = nepim_global.tcp_keepalive_send_delay;
+    }
+  }
+  else {
+    if (server_ka_timeout == -2) {
+      server_ka_timeout = nepim_global.udp_keepalive_recv_timer;
+    }
+    if (server_ka_delay == -2) {
+      server_ka_delay = nepim_global.udp_keepalive_send_delay;
+    }
+  }
+
+  opt->must_send            = server_send;
+  opt->bit_rate             = bit_rate;
+  opt->pkt_rate             = pkt_rate;
+  opt->stat_interval        = stat_interval;
+  opt->test_duration        = test_duration;
+  opt->write_delay          = write_delay;
+  opt->keepalive_must_send  = server_ka_send;
+  opt->keepalive_require    = server_ka_require;
+  opt->keepalive_timeout    = server_ka_timeout;
+  opt->keepalive_send_delay = server_ka_delay;
+  opt->seed                 = seed;
+  opt->verify_data          = verify_data;
+  opt->random_fill          = random_fill;
+  opt->fill_byte            = (unsigned char) fill_byte;
+  opt->pause_duration       = pause_duration;
+  opt->socket_keepalive     = socket_keepalive;
+  opt->nagle                = nagle;
+  opt->overhead             = overhead;
+  opt->sweep_random         = sweep_random;
+  opt->sweep_step           = sweep_step;
+  opt->write_floor          = write_floor;
+  opt->write_ceil           = write_ceil;
 
   return NEPIM_GREET_PARSE_OK;
 }
