@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: server.c,v 1.79 2007/03/23 12:40:05 evertonm Exp $ */
+/* $Id: server.c,v 1.80 2007/08/30 15:08:00 evertonm Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -679,8 +679,8 @@ static void *on_tcp_keepalive_require(oop_source *src, struct timeval tv, void *
     int sd = pipe->sd;
 
     fprintf(stderr, 
-            "%d: breaking pipe: peer not sending keepalives?\n",
-            sd);
+            "%d: %s\n",
+            sd, NEPIM_MSG_KEEPALIVES_MISS);
 
     if (!session->duration_done)
       report_broken_pipe_stat(stdout, pipe);
@@ -727,9 +727,9 @@ static void tcp_pipe_start(int sd)
 
 #if 0
       fprintf(stderr, 
-              "DEBUG %s %s: %d: scheduling sending of keepalives\n",
+              "DEBUG %s %s: %d: %s\n",
               __FILE__, __PRETTY_FUNCTION__,
-              sd);
+              sd, NEPIM_MSG_KEEPALIVES_SCHED);
 #endif
       
       session->tv_keepalive_send_next = OOP_TIME_NOW;
