@@ -18,13 +18,15 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: session.c,v 1.16 2007/03/22 21:56:53 evertonm Exp $ */
+/* $Id: session.c,v 1.17 2007/08/17 17:12:48 evertonm Exp $ */
 
 #include <string.h>
 #include <assert.h>
+#include <time.h>
 
 #include "session.h"
 #include "common.h"
+#include "rand.h"
 
 void nepim_session_init(nepim_session_t *session, const nepim_greet_t *opt,
                         const struct sockaddr *remote, socklen_t remote_len,
@@ -69,17 +71,19 @@ void nepim_session_init(nepim_session_t *session, const nepim_greet_t *opt,
   session->write_floor             = opt->write_floor;
   session->write_ceil              = opt->write_ceil;
 
-  session->duration_done       = 0;
-  session->total_reads         = 0;
-  session->total_writes        = 0;
-  session->interval_reads      = 0;
-  session->interval_writes     = 0;
-  session->byte_total_sent     = 0;
-  session->byte_total_recv     = 0;
-  session->byte_interval_sent  = 0;
-  session->byte_interval_recv  = 0;
-  session->keepalives_recv     = 0;
-  session->write_sweep_current = session->write_floor;
+  session->duration_done        = 0;
+  session->total_reads          = 0;
+  session->total_writes         = 0;
+  session->interval_reads       = 0;
+  session->interval_writes      = 0;
+  session->byte_total_sent      = 0;
+  session->byte_total_recv      = 0;
+  session->byte_interval_sent   = 0;
+  session->byte_interval_recv   = 0;
+  session->keepalives_recv      = 0;
+  session->write_sweep_rand_ctx = time(0); /* random seed (see rand.c) */
+  session->udp_dst_random_ctx   = session->write_sweep_rand_ctx;
+  session->write_sweep_current  = session->write_floor;
 }
 
 void nepim_session_write_add(nepim_session_t *session, int len)
@@ -102,27 +106,6 @@ void nepim_session_read_add(nepim_session_t *session, int len)
   ++session->interval_reads;
 }
 
-static int nepim_rand_next(int ctx, int min, int max)
-{
-  long rand;
-
-  assert(min <= max);
-
-  /* FIXME: better generator ? */
-
-  rand = QRANDOM(ctx); 
-
-  if (rand < 0)
-    rand = -rand;
-
-  rand = rand % (1 + max - min) + min;
-
-  assert(rand >= min);
-  assert(rand <= max);
-
-  return rand;
-}
-
 int nepim_write_sweep(nepim_session_t *session)
 {
   int to_write = session->write_sweep_current;
@@ -130,7 +113,7 @@ int nepim_write_sweep(nepim_session_t *session)
   assert(session->write_floor <= session->write_ceil);
 
   if (session->sweep_random) {
-    session->write_sweep_current = nepim_rand_next(session->write_sweep_current,
+    session->write_sweep_current = nepim_rand_next(&session->write_sweep_rand_ctx,
 						   session->write_floor,
 						   session->write_ceil);
   }
