@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: slot.c,v 1.48 2007/08/17 17:12:48 evertonm Exp $ */
+/* $Id: slot.c,v 1.50 2007/08/17 18:28:25 evertonm Exp $ */
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -218,6 +218,19 @@ static void slot_buf_write(nepim_slot_t *slot, char *buf, size_t buf_size, uint8
   nepim_udp_hdr_write(&hdr, buf, buf_size);
 }
 
+/*
+  remove 224.0.0.224 to skip the multicast block,
+  because the linux UDP stack doesn't seem to like
+  them used in this way (unicast socket mode?)
+
+  we remove 224 from both sides (1st and last byte)
+  because we don't want/need to test endianness.
+
+  alternatively, we could work-around this elsewhere.
+*/
+#define NEPIM_ADDR32_NOMULTICAST(a) ((a) &= ~0xE00000E0)
+#define NEPIM_ADDR32_NOZERONET(a) ((a) |= 0x01000001)
+
 int nepim_slot_buf_sendto(nepim_slot_t *slot, char *buf, size_t buf_size, uint8_t type)
 {
   ssize_t wr;
@@ -231,15 +244,18 @@ int nepim_slot_buf_sendto(nepim_slot_t *slot, char *buf, size_t buf_size, uint8_
     case PF_INET:
       {
 	uint32_t random_addr = nepim_urand_next(&slot->session.udp_dst_random_ctx);
+	NEPIM_ADDR32_NOMULTICAST(random_addr);
+	NEPIM_ADDR32_NOZERONET(random_addr);
 	slot->session.remote.inet.sin_addr.s_addr = random_addr;
       }
       break;
     case PF_INET6:
       {
 	int i;
-	for (i = 0; i < 4; ++i)
-	  slot->session.remote.inet6.sin6_addr.in6_u.u6_addr32[i] =
-	    nepim_urand_next(&slot->session.udp_dst_random_ctx);
+	for (i = 0; i < 4; ++i) {
+	  uint32_t random_addr = nepim_urand_next(&slot->session.udp_dst_random_ctx);
+	  slot->session.remote.inet6.sin6_addr.in6_u.u6_addr32[i] = random_addr;
+	}
       }
       break;
     default:
