@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: udp_client.c,v 1.81 2007/08/16 22:02:13 evertonm Exp $ */
+/* $Id: udp_client.c,v 1.83 2007/08/31 12:03:44 evertonm Exp $ */
 
 #include <stdio.h>
 #include <string.h>
@@ -87,8 +87,9 @@ static void *on_udp_keepalive_require(oop_source *src, struct timeval tv, void *
 
   if (session->keepalives_recv < 1) {
     fprintf(stderr, 
-            "%d %d-%d: broken slot: peer not sending keepalives?\n",
-            slot->udp_sd, slot->index, slot->index_remote);
+            "%d %d-%d: broken slot: %s\n",
+            slot->udp_sd, slot->index, slot->index_remote,
+	    NEPIM_MSG_KEEPALIVES_MISS);
 
     if (!session->duration_done)
       report_broken_slot_stat(stdout, slot);
@@ -197,9 +198,10 @@ static void udp_slot_start(nepim_slot_t *slot)
 
 #if 0
       fprintf(stderr, 
-              "DEBUG %s %s: %d %d-%d: scheduling sending of keepalives\n",
+              "DEBUG %s %s: %d %d-%d: %s\n",
               __FILE__, __PRETTY_FUNCTION__,
-              slot->udp_sd, slot->index, slot->index_remote);
+              slot->udp_sd, slot->index, slot->index_remote,
+	      NEPIM_MSG_KEEPALIVES_SCHED);
 #endif
       
       session->tv_keepalive_send_next = OOP_TIME_NOW;
@@ -651,7 +653,7 @@ static void udp_write_greet(nepim_slot_t *slot)
     }
 
     fprintf(stderr, 
-            "%d %d-%d: max. greetings reached (%d/%d) - server not responding\n",
+            "%d %d-%d: max. greetings reached (%d/%d) - server not responding (see option -g)\n",
             sd, slot->index, slot->index_remote,
             slot->greetings_sent, nepim_global.max_greetings);
 
@@ -660,8 +662,9 @@ static void udp_write_greet(nepim_slot_t *slot)
     return;
   }
 
-  fprintf(stderr, "%d %d-%d: sending greetings\n",
-          sd, slot->index, slot->index_remote);
+  fprintf(stderr, "%d %d-%d: sending greetings (%d/%d)\n",
+          sd, slot->index, slot->index_remote,
+	  slot->greetings_sent, nepim_global.max_greetings);
 
   result = slot_greet_write(slot);
   if (result) {
