@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: udp_server.c,v 1.105 2007/03/23 12:40:05 evertonm Exp $ */
+/* $Id: udp_server.c,v 1.106 2007/08/30 15:08:01 evertonm Exp $ */
 
 
 #include <stdio.h>
@@ -634,8 +634,9 @@ static void *on_udp_keepalive_require(oop_source *src, struct timeval tv, void *
 
   if (session->keepalives_recv < 1) {
     fprintf(stderr, 
-	    "%d %d-%d: broken slot: peer not sending keepalives?\n",
-	    slot->udp_sd, slot->index, slot->index_remote);
+	    "%d %d-%d: broken slot: %s\n",
+	    slot->udp_sd, slot->index, slot->index_remote,
+	    NEPIM_MSG_KEEPALIVES_MISS);
 
     if (!session->duration_done)
       report_broken_slot_stat(stdout, slot);
@@ -678,9 +679,10 @@ static void udp_slot_start(int local_slot)
 
 #if 0
       fprintf(stderr, 
-	      "DEBUG %s %s: %d %d-%d: scheduling sending of keepalives\n",
+	      "DEBUG %s %s: %d %d-%d: %s\n",
 	      __FILE__, __PRETTY_FUNCTION__,
-	      slot->udp_sd, slot->index, slot->index_remote);
+	      slot->udp_sd, slot->index, slot->index_remote,
+	      NEPIM_MSG_KEEPALIVES_SCHED);
 #endif
       
       session->tv_keepalive_send_next = OOP_TIME_NOW;
